@@ -1,9 +1,9 @@
 package Dancer::Cookie;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: class representing cookies
-$Dancer::Cookie::VERSION = '1.3514_02'; # TRIAL
+$Dancer::Cookie::VERSION = '1.3514_03'; # TRIAL
 
-$Dancer::Cookie::VERSION = '1.351402';use strict;
+$Dancer::Cookie::VERSION = '1.351403';use strict;
 use warnings;
 
 use Carp;
@@ -28,11 +28,14 @@ sub init {
 
     # If we have a same_site attribute, ensure it's sane:
     if (my $same_site = $self->same_site) {
-        if ($same_site !~ m{^(Strict|Lax|None)$}) {
+        if ($same_site !~ m{^(Strict|Lax|None)$}i) {
             Carp::croak(
                 "Invalid same_site value '$same_site'"
                 . " - must be 'Strict', 'Lax' or 'None', see RFC6265bis"
             );
+        } else {
+            # Normalise case
+            $self->same_site(ucfirst lc $same_site);
         }
     }
 }
@@ -145,7 +148,7 @@ Dancer::Cookie - class representing cookies
 
 =head1 VERSION
 
-version 1.3514_02
+version 1.3514_03
 
 =head1 SYNOPSIS
 
